@@ -1,7 +1,4 @@
 import click
-import requests
-
-from alpa_conf.metadata import Metadata
 
 from alpa.cli.alpa_repo import create, delete, request_package
 from alpa.cli.local_repo import (
@@ -13,9 +10,14 @@ from alpa.cli.local_repo import (
     list,
     genspec,
     add,
+    get_pkg_archive,
+    mockbuild,
+    create_packit_config,
 )
 from alpa.repository import AlpaRepo
 
+# TODO: get rid of the repetitive _Repo(Path(getcwd()))
+
 
 @click.group()
 def entry_point() -> None:
@@ -32,23 +34,6 @@ def clone(url: str) -> None:
     AlpaRepo.clone(url)
 
 
-@entry_point.command("get-pkg-archive")
-def get_pkg_archive() -> None:
-    """Gets archive from package config"""
-    metadata = Metadata()
-    resp = requests.get(metadata.upstream_url, allow_redirects=True)
-    if not resp.ok:
-        raise ConnectionError(
-            f"Couldn't download source from {metadata.upstream_url}. "
-            f"Reason: {resp.reason}"
-        )
-
-    with open(
-        f"{metadata.package_name}-{metadata.upstream_version}.tar.gz", "wb"
-    ) as archive:
-        archive.write(resp.content)
-
-
 entry_point.add_command(create)
 entry_point.add_command(delete)
 entry_point.add_command(request_package)
@@ -61,6 +46,9 @@ entry_point.add_command(push)
 entry_point.add_command(list)
 entry_point.add_command(genspec)
 entry_point.add_command(add)
+entry_point.add_command(get_pkg_archive)
+entry_point.add_command(mockbuild)
+entry_point.add_command(create_packit_config)
 
 
 if __name__ == "__main__":
